@@ -26,9 +26,7 @@
  */
 #include "iperf_config.h"
 
-#ifdef HAVE_STDINT_H
 #include <stdint.h>
-#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
